@@ -346,7 +346,7 @@ class TestPLS(object):
         test_model = PLS()
         test_model.fit(X_test_data, Y_test_data, random_state = 2)
 
-        expected = array([17.72518645, 20.89734763, 16.81212398, 20.49478103, 21.33611356])
+        expected = array([13.92958513, 18.65835615, 14.64250661, 17.51150011, 17.53666052])
         expected_95_lim = 19.791328565268596
 
         assert expected == pytest.approx(test_model.SPEs_X(X_test_data.iloc[:5]))
@@ -373,36 +373,26 @@ class TestPLS(object):
         test_model = PLS()
         test_model.fit(X_test_data, Y_test_data, random_state = 2)
         
-        expected = array([[ 1.11252687e+00, -4.62942516e+00, -7.33401238e-01, -7.50251539e-01,
-                           -9.48160094e-02, -1.60347239e+00,  1.74671715e-01,  2.55057138e-01,
-                           -3.31612562e-01, -2.04254373e+00,  1.80111519e-02, -2.50946841e-01,
-                            3.21165469e-01,  4.49492145e-03,  3.50094616e-01,  1.35828629e+00,
-                            4.09259624e-01, -1.76923634e-03, -1.07336033e+00,  2.46038381e-01,
-                            1.33630995e-01],
-                          [ 1.23996571e+00, -1.31505444e+00, -4.01094173e-01,  3.06478259e-02,
-                            4.84448214e-03, -6.64498616e-01, -1.23131262e+00,  2.60542349e-03,
-                           -6.83652533e-02, -1.76463062e+00,  1.75517908e-03, -1.55125238e-01,
-                            1.72197070e-01, -1.86372701e-02,  4.07337723e-01,  1.75430364e+00,
-                            5.57176467e-01, -1.25660257e-01, -3.11599550e-01,  7.73681261e-02,
-                            3.72162416e-01],
-                          [ 3.33463401e-01, -8.62497125e-01, -3.60460957e-01,  1.24413993e-01,
-                           -1.28198890e-02, -7.11969023e-01,  1.72885473e-02,  3.56442990e-02,
-                           -1.41772328e-01, -1.37854076e+00, -1.41289772e-02, -2.32049306e-01,
-                            3.51592865e-02,  3.69843054e-03,  1.37037237e-01,  6.49447995e-01,
-                            4.24618165e-01,  3.92665819e-03, -1.07272258e+00,  1.21942316e-01,
-                            6.47426681e-02],
-                          [ 8.39320238e-02, -4.19522932e+00, -3.58979056e-01, -7.03722785e-02,
-                           -4.48532888e-02, -1.04723650e+00,  2.76987804e-01, -6.82584646e-02,
-                            2.52113823e-01, -1.90538590e+00, -5.72993269e-02, -4.02679289e-01,
-                            1.57714762e-01,  4.48192301e-03,  2.22629770e-01,  7.77241215e-01,
-                            2.15857339e-01, -8.56712416e-05, -1.66610048e+00,  1.92721602e-01,
-                            2.23230991e-01],
-                          [ 8.24758206e-01, -6.63191901e+00, -1.86278168e-01, -3.92126940e-01,
-                           -7.01806151e-02, -1.34739677e+00,  3.78024256e-01,  7.44531385e-02,
-                            3.45469694e-01, -2.49466021e+00, -8.00003540e-02, -3.85557145e-01,
-                            2.31945117e-01,  7.21203047e-03,  3.19638970e-01,  1.18995117e+00,
-                            2.79500695e-01, -7.01913099e-03, -1.74014059e+00,  2.57566472e-01,
-                            1.81400432e-01]])
+        expected = array([[-2.68813179,  4.46676661,  1.16411168,  1.78458893,  0.46500642,  3.24105437,
+                           -1.10486586, -1.13835333,  0.85546069,  2.54200573, -0.10633094,  0.91625753,
+                           -0.57238509, -0.26433001, -1.10650487, -3.37405811, -0.9389879 , -0.53151721,
+                            1.82360895, -1.17160388, -0.41350782],
+                          [-3.37680507,  1.49945945,  0.91284348,  0.75835695,  0.07930331,  1.95769566,
+                           -6.39584051, -1.61754788,  0.25143695,  2.28770524, -0.07457704,  0.82621281,
+                           -0.58032044, -0.41425647, -1.90102045, -4.49278179, -1.47262003, -1.09349948,
+                            0.67942955, -1.07026981, -1.23916743],
+                          [-0.75607153,  0.86197732,  0.53895734, -0.37722553,  0.06354511,  1.75099815,
+                           -0.0338949 , -0.13635704,  0.49968743,  1.7614151 ,  0.06984811,  0.78479944,
+                           -0.08874249, -0.08565511, -0.37956893, -1.64726313, -0.92324428, -0.03344398,
+                            2.12687695, -0.62231493, -0.20493329],
+                          [-0.19016355,  4.14312131,  0.58327337,  0.1789767 ,  0.24929311,  2.20764961,
+                           -1.09391697,  0.23251304, -0.70849432,  2.39253836,  0.3674764 ,  1.43757856,
+                           -0.29105614, -0.19409341, -0.65993613, -1.94638118, -0.49475214, -0.01456232,
+                            2.95778356, -1.00696253, -0.69394549],
+                          [-1.91120568,  6.39272847,  0.28218251,  0.87350903,  0.31597666,  2.78945886,
+                           -1.0861929 , -0.26840563, -0.93852792,  3.12229161,  0.41067136,  1.32544647,
+                           -0.41745842, -0.19605014, -0.92612126, -2.97023389, -0.6217352 ,  0.12695167,
+                            3.03479051, -1.18189841, -0.56180621]])
 
         assert expected == pytest.approx(test_model.contributions_scores_ind(X_test_data.iloc[:5]))
     
@@ -415,36 +405,36 @@ class TestPLS(object):
         test_model = PLS()
         test_model.fit(X_test_data, Y_test_data, random_state = 2)
 
-        expected = array([[-4.98353719e-01, -2.05472738e-01,  1.69990850e+00, -1.40950991e-02,
-                            5.23150683e-02,  8.17079276e-01, -3.09394493e-02, -1.50798153e+00,
-                           -2.90893382e-02, -1.95750690e-01, -7.63820808e-02,  2.79742817e-01,
-                           -7.83554532e-01, -2.18884919e+00, -8.08031872e-03, -2.59895218e+00,
-                           -1.89345614e-04, -3.28059324e-01,  4.29379016e+00, -2.07242721e+00,
-                            4.41738920e-02],
-                          [-4.37791690e-01,  1.32922546e-01,  1.21901639e-01, -7.02917528e-01,
-                            3.88450246e-04,  1.75012730e+00,  1.55071654e-03, -2.71209398e-01,
-                           -4.59048736e-02,  4.55055526e-02, -3.13862511e-01,  1.92700329e-01,
-                           -6.14945492e-01, -2.68598655e+00, -3.17264700e-01, -5.91291624e+00,
-                           -6.09640521e-01, -3.65332009e-01,  1.92254249e+00, -3.87589435e+00,
-                           -5.76042735e-01],
-                          [-3.54322550e-01, -6.00828942e-01,  7.76955840e-01, -5.21343811e-01,
-                            1.57359702e-01,  1.47113166e+00, -9.77092748e-01, -7.00204392e-01,
-                            3.61100686e-01,  1.28128485e-03, -8.95999470e-04,  4.25918296e-01,
-                           -1.25243213e-01, -2.83015838e+00, -1.17271732e-01, -1.68150207e+00,
-                           -8.89059752e-02, -1.29875703e-02,  3.70031091e+00, -1.89380751e+00,
-                            1.35007029e-02],
-                          [-7.29511821e-03, -1.52942809e-05,  6.08045828e-01, -1.40858822e-04,
-                            1.26731605e-01,  7.46353023e-01, -1.90607203e+00, -1.86535085e-01,
-                           -1.31286592e+00, -8.87906895e-03,  7.33555910e-02,  1.02476816e+00,
-                           -4.12859628e-01, -4.01445452e+00, -3.43148295e-01, -1.59982208e+00,
-                            9.03859253e-03,  2.76797538e-02,  5.12391070e+00, -2.93318623e+00,
-                           -2.96236532e-02],
-                          [-3.88430668e-01, -1.51847793e-02,  1.07200255e+00,  3.40451766e-02,
-                            1.03505175e-01,  6.04202540e-01, -1.26289540e+00, -7.07673907e-01,
-                           -1.88529559e+00, -9.26016869e-02,  9.31628943e-02,  5.32123462e-01,
-                           -5.63653266e-01, -3.77562005e+00, -5.63786563e-02, -1.94623436e+00,
-                            7.12808294e-02,  2.86202058e-01,  5.39927168e+00, -2.43130504e+00,
-                            1.50437897e-02]])
+        expected = array([[-3.64328547e-01, -6.38937288e-04,  9.73736182e-02,  1.51182931e-02,
+                            7.53956542e-02,  1.46803910e+00,  1.52906289e-02, -4.51815515e-01,
+                           -1.00337293e-03, -1.63992452e-03, -3.98404905e-01,  1.13284446e-02,
+                           -2.34267664e-03, -2.57429619e+00, -1.94856653e-01, -2.25107561e+00,
+                           -1.78824587e-02, -2.24010935e-01,  2.57683640e+00, -3.07836421e+00,
+                            1.09543046e-01],
+                          [-1.23251781e-01, -9.76468033e-04,  2.14091056e-01, -1.86344336e-01,
+                            2.97791854e-02,  1.70056432e+00, -1.24775744e-01, -2.76168190e-01,
+                           -7.75524936e-03, -5.19458421e-02, -8.95938127e-01, -2.72155305e-03,
+                           -7.83455641e-03, -2.95613852e+00, -2.66379082e-01, -3.99433051e+00,
+                           -2.08046924e-01, -3.05150957e-01,  1.65589737e+00, -5.37043633e+00,
+                           -2.79830056e-01],
+                          [-3.06333466e-01, -7.48769923e-02,  6.19111482e-02, -4.36039087e-01,
+                            1.33768255e-01,  1.71436212e+00, -1.24175627e-01, -4.25762021e-01,
+                            6.54466481e-01,  1.49188545e-02, -1.90108226e-01,  7.85666212e-02,
+                            2.95837155e-02, -2.81089627e+00, -4.08420726e-01, -1.42222331e+00,
+                           -2.31367284e-01,  1.44681488e-02,  2.54863534e+00, -2.92933396e+00,
+                            3.22889433e-02],
+                          [-8.50045281e-03,  2.17047591e-01, -2.01780208e-02,  5.70738385e-03,
+                            5.70880934e-02,  7.77003976e-01, -5.89509926e-01, -5.96395210e-02,
+                           -8.99336190e-01,  1.45831824e-07, -7.23218607e-02,  2.01905939e-01,
+                            5.11151596e-04, -4.16661047e+00, -1.12036857e+00, -1.31886241e+00,
+                           -1.05110751e-02,  2.11386812e-01,  3.31487824e+00, -4.46013225e+00,
+                           -2.84986307e-08],
+                          [-2.99542639e-01,  2.45587573e-01,  5.22057268e-07,  1.24916710e-01,
+                            1.02785830e-01,  1.05673720e+00, -2.39052144e-01, -1.46022300e-01,
+                           -1.32773090e+00,  2.17513673e-04, -2.89518373e-02,  5.82666256e-02,
+                            6.60330288e-03, -4.04158765e+00, -4.28687880e-01, -1.62725837e+00,
+                            3.00489597e-03,  5.68344733e-01,  3.32397088e+00, -3.85501976e+00,
+                            5.23712528e-02,]])
 
         assert expected == pytest.approx(test_model.contributions_SPE_X(X_test_data.iloc[:5]))
         
\ No newline at end of file
