@@ -334,7 +334,7 @@ class SMB_PLS:
         else:
             latent_variables = sum(latent_variables)
 
-        result = scores @ self.x_weights_star[:latent_variables, :] 
+        result = scores @ self.p[:latent_variables, :] 
         
         return result
     
@@ -438,7 +438,7 @@ class SMB_PLS:
         
         return T2s
     
-    def Hotellings_T2_block(self, X, block, latent_variables = None):
+    #def Hotellings_T2_block(self, X, block, latent_variables = None):
 
         """
         Calculates the Hotelling's T² for the X samples on the superlevel.
@@ -457,7 +457,7 @@ class SMB_PLS:
         """
 
 
-        return T2s_block
+    #    return T2s_block
         
     def SPEs_X(self, X, latent_variables = None): 
         
@@ -539,14 +539,14 @@ class SMB_PLS:
         if isinstance(X, DataFrame) : X = X.to_numpy()
 
         scores = self.transform(X, latent_variables = latent_variables)
-        scores = (scores / std(scores, axis = 0) ** 2)
+        scores = (scores / std(scores, axis = 0)) ** 2
 
         if latent_variables == None : 
             latent_variables = sum(self.latent_variables)
         else:
             latent_variables = sum(latent_variables)
 
-        contributions = X * (scores @ (self.x_weights_star[:latent_variables, :] ** 2) ** 1 / 2)
+        contributions = X * (scores @ (self.x_weights_star[:latent_variables, :] ** 2) ** (1 / 2))
 
         return contributions
     
