@@ -1,6 +1,7 @@
 from .PCA import PCA
 from .PLS import PLS
 from .MB_PCA import MB_PCA
+from .MB_PLS import MB_PLS
 from .SMB_PLS import SMB_PLS
 
-__all__ = ['PCA', 'PLS', 'MB_PCA', 'SMB_PLS']
+__all__ = ['PCA', 'PLS', 'MB_PCA', 'MB_PLS', 'SMB_PLS']
